@@ -16,7 +16,7 @@
  *
  *  Author: Tom Zoerner
  *
- *  $Id: epgacqsrv.h,v 1.6 2003/06/28 10:25:57 tom Exp tom $
+ *  $Id: epgacqsrv.h,v 1.9 2004/06/19 19:52:42 tom Exp tom $
  */
 
 #ifndef __EPGACQSRV_H
@@ -77,11 +77,12 @@ typedef struct MSG_STRUCT_STATS_IND_STRUCT
          EPGDB_BLOCK_COUNT    count[2];
          EPGDB_ACQ_AI_STATS   ai;
          EPGDB_ACQ_TTX_STATS  ttx;
+         EPG_STREAM_STATS     stream;
          EPGDB_ACQ_VPS_PDC    vpsPdc;
          EPGDB_HIST           hist;
          uint16_t             histIdx;
          uint32_t             nowNextMaxAcqRepCount;
-         uint32_t             resv_align3; // 64-bit alignment for Sparc
+         time_t               lastStatsUpdate;
       } update;
    } u;
 } MSG_STRUCT_STATS_IND;
@@ -103,7 +104,8 @@ typedef struct
    uint32_t  blockCompatVersion;      // version of EPG database block format
    uint32_t  protocolCompatVersion;   // protocol version
    uint32_t  swVersion;               // software version (informative only)
-   uint8_t   reserved[64];            // reserved for future additions
+   int32_t   daemon_pid;
+   uint8_t   reserved[60];            // reserved for future additions
 } MSG_STRUCT_CONNECT_CNF;
 
 typedef struct
