@@ -18,7 +18,7 @@
 #
 #  Author: Tom Zoerner
 #
-#  $Id: dlg_dump.tcl,v 1.6 2004/05/31 14:33:16 tom Exp tom $
+#  $Id: dlg_dump.tcl,v 1.9 2004/12/29 12:02:58 tom Exp tom $
 #
 set dumpdb_pi 1
 set dumpdb_xi 1
@@ -42,6 +42,7 @@ set dumphtml_sel 1
 set dumphtml_sel_count 25
 set dumphtml_type 3
 set dumphtml_hyperlinks 1
+set dumphtml_text_fmt 1
 set dumphtml_use_colsel 0
 set dumphtml_colsel {}
 set dumphtml_popup 0
@@ -159,9 +160,7 @@ proc DoDbRawDump {} {
 
    if [DlgDump_CheckOutputFile .dumpdb dumpdb_filename .txt 1 0] {
 
-      C_DumpRawDatabase $dumpdb_filename \
-                        $dumpdb_pi $dumpdb_xi $dumpdb_ai $dumpdb_ni \
-                        $dumpdb_oi $dumpdb_mi $dumpdb_li $dumpdb_ti
+      C_DumpRawDatabase $dumpdb_filename
 
       # save the settings to the rc/ini file
       UpdateRcFile
@@ -249,7 +248,7 @@ proc DoDbTabsDump {} {
 ##
 proc PopupDumpHtml {} {
    global dumphtml_filename dumphtml_type dumphtml_file_append dumphtml_file_overwrite
-   global dumphtml_sel dumphtml_sel_count dumphtml_hyperlinks
+   global dumphtml_sel dumphtml_sel_count dumphtml_hyperlinks dumphtml_text_fmt
    global font_fixed fileImage
    global dumphtml_popup
 
@@ -311,6 +310,8 @@ proc PopupDumpHtml {} {
       pack .dumphtml.opt4.row1 -side top -anchor nw -fill x
       checkbutton .dumphtml.opt4.chk1 -text "Add hyperlinks to titles" -variable dumphtml_hyperlinks
       pack .dumphtml.opt4.chk1 -side top -anchor nw
+      checkbutton .dumphtml.opt4.chk2 -text "Apply text format options in user-defined columns" -variable dumphtml_text_fmt
+      pack .dumphtml.opt4.chk2 -side top -anchor nw
       pack .dumphtml.opt4 -side top -pady 5 -padx 10 -fill x
 
       frame .dumphtml.cmd
@@ -392,7 +393,7 @@ proc PopupHtmlColumnSelection {} {
    global dumphtml_colsel
    global htmlcols_ailist htmlcols_selist colsel_names
    global htmlcols_popup
-   global text_bg
+   global text_fg text_bg
 
    if {$htmlcols_popup == 0} {
       CreateTransientPopup .htmlcols "HTML Export Columns Selection"
@@ -401,7 +402,8 @@ proc PopupHtmlColumnSelection {} {
       FillColumnSelectionDialog .htmlcols.all htmlcols_ailist htmlcols_selist $dumphtml_colsel 1
 
       message .htmlcols.intromsg -text "Select which types of attributes you want to have\ndisplayed for each TV programme in the HTML document:" \
-                                 -aspect 2500 -borderwidth 2 -relief ridge -background $text_bg -pady 5
+                                 -aspect 2500 -borderwidth 2 -relief ridge \
+                                 -foreground $text_fg -background $text_bg -pady 5
       pack .htmlcols.intromsg -side top -fill x -expand 1
 
       frame .htmlcols.all
@@ -435,7 +437,8 @@ proc HtmlDump_ApplyColumnSelection {} {
 # callback for "Export" button
 proc HtmlDump_Start {} {
    global dumphtml_filename dumphtml_type dumphtml_file_append dumphtml_file_overwrite
-   global dumphtml_sel dumphtml_hyperlinks dumphtml_use_colsel dumphtml_colsel dumphtml_sel_count
+   global dumphtml_sel dumphtml_hyperlinks dumphtml_text_fmt
+   global dumphtml_use_colsel dumphtml_colsel dumphtml_sel_count
    global pilistbox_cols
 
    if {$dumphtml_sel == 1} {
@@ -447,7 +450,7 @@ proc HtmlDump_Start {} {
       }
    }
 
-   # select a column to user for hyperlinks
+   # select a column to use for hyperlinks
    set hyperCol [lsearch -exact $pilistbox_cols title]
    if {$hyperCol == -1} {set hyperCol 0}
 
@@ -464,6 +467,7 @@ proc HtmlDump_Start {} {
                     [expr $dumphtml_sel == 2] \
                     [expr ($dumphtml_sel == 2) ? 1 : ((($dumphtml_sel == 0) ? -1 : $dumphtml_sel_count))] \
                     [expr ($dumphtml_hyperlinks && ($dumphtml_type == 3)) ? $hyperCol : -1] \
+                    $dumphtml_text_fmt \
                     $colsel
 
          # save the settings to the rc/ini file
