@@ -16,7 +16,7 @@
  *
  *  Author: Tom Zoerner
  *
- *  $Id: epgmain.h,v 1.18 2002/01/26 15:20:12 tom Exp tom $
+ *  $Id: epgmain.h,v 1.23 2003/09/19 21:55:37 tom Exp tom $
  */
 
 #ifndef __EPGMAIN_H
@@ -29,20 +29,25 @@ extern char epg_rcs_id_str[];
 
 // Interface to Tcl/Tk interpreter for UI modules
 #ifdef _TCL
+#define TCL_COMM_BUF_SIZE  1000
 extern Tcl_Interp *interp;
-extern char comm[1000];
+// add one extra byte at the end of the comm buffer for overflow detection
+extern char comm[TCL_COMM_BUF_SIZE + 1];
 
-int eval_check(Tcl_Interp *i, char *c);
-int eval_global(Tcl_Interp *interp, char *cmd);
 void AddMainIdleEvent( Tcl_IdleProc *IdleProc, ClientData clientData, bool unique );
 bool RemoveMainIdleEvent( Tcl_IdleProc * IdleProc, ClientData clientData, bool matchData );
 
 bool EpgMain_StartDaemon( void );
 bool EpgMain_StopDaemon( void );
+#ifdef WIN32
+bool EpgMain_CheckDaemon( void );
+#endif
 bool IsDemoMode( void );
 #endif  // _TCL
 
 // Access to databases from UI and acq-ctl
 extern EPGDB_CONTEXT * pUiDbContext;
 
+time_t EpgGetUiMinuteTime( void );
+
 #endif  // __EPGMAIN_H
