@@ -16,24 +16,26 @@
  *
  *  Author: Tom Zoerner
  *
- *  $Id: pifilter.h,v 1.7 2001/05/19 14:58:25 tom Exp tom $
+ *  $Id: pifilter.h,v 1.11 2003/09/19 21:57:06 tom Exp tom $
  */
 
 #ifndef __PIFILTER_H
 #define __PIFILTER_H
 
 
-#ifndef __PIFILTER_C
 // search context for pi listbox
-extern const FILTER_CONTEXT *pPiFilterContext;
-#endif
+extern FILTER_CONTEXT *pPiFilterContext;
 
 // Initialization and destruction - Interface to the EPG main module
 void PiFilter_Create( void );
 void PiFilter_Destroy( void );
 
 // Interface to ui control module
-void PiFilter_UpdateNetwopList( void );
+void PiFilter_SetNetwopPrefilter( void );
 void PiFilter_Expire( void );
 
+// Interface to PI listbox column output
+bool PiFilter_ContextCacheMatch( const PI_BLOCK * pPiBlock, uint idx );
+const FILTER_CONTEXT * PiFilter_ContextCacheGet( uint idx );
+
 #endif  // __PIFILTER_H
