@@ -16,7 +16,7 @@
  *
  *  Author: Tom Zoerner
  *
- *  $Id: vbidecode.h,v 1.15 2001/02/25 15:59:43 tom Exp tom $
+ *  $Id: vbidecode.h,v 1.18 2003/04/12 17:51:21 tom Exp tom $
  */
 
 #ifndef __VBIDECODE_H
@@ -27,7 +27,8 @@
 // Declaration of service interface functions
 //
 void VbiDecodeLine( const uchar *lbuf, int line, bool doVps );
-void VbiDecodeLostFrame( void );
+bool VbiDecodeStartNewFrame( uint frameSeqNo );
+void VbiDecodeSetSamplingRate( ulong sampling_rate, uint startLine );
 
 
 #endif // __VBIDECODE_H
