@@ -21,7 +21,7 @@
  *
  *  Author: Thorsten Zoerner
  *
- *  $Id: tvsim_main.c,v 1.24 2004/03/28 13:18:17 tom Exp tom $
+ *  $Id: tvsim_main.c,v 1.27 2004/12/12 14:53:06 tom Exp tom $
  */
 
 #define DEBUG_SWITCH DEBUG_SWITCH_TVSIM
@@ -63,6 +63,9 @@
 #include "tvsim/tvsim_gui.h"
 #include "tvsim/tvsim_version.h"
 
+#if defined(__FreeBSD__) || defined(__NetBSD__)
+#include <machine/ioctl_bt848.h>
+#endif
 
 // prior to 8.4 there's a SEGV when evaluating const scripts (Tcl tries to modify the string)
 #if (TCL_MAJOR_VERSION > 8) || ((TCL_MAJOR_VERSION == 8) && (TCL_MINOR_VERSION >= 4))
@@ -167,6 +170,7 @@ static Display * TvSim_GetTvDisplay( void )
 //
 static int Xawtv_QueryRemoteCommand( Window wid, char * pBuffer, int bufLen )
 {
+   Tk_ErrorHandler errHandler;
    Display *dpy;
    Atom  type;
    int   format;
@@ -178,6 +182,9 @@ static int Xawtv_QueryRemoteCommand( Window wid, char * pBuffer, int bufLen )
    dpy = TvSim_GetTvDisplay();
    if (dpy != NULL)
    {
+      // push an /dev/null handler onto the stack that catches any type of X11 error events
+      errHandler = Tk_CreateErrorHandler(dpy, -1, -1, -1, (Tk_ErrorProc *) NULL, (ClientData) NULL);
+
       args = NULL;
       if ( (XGetWindowProperty(dpy, wid, xawtv_remote_atom, 0, (65536 / sizeof (long)), False, XA_STRING,
                                &type, &format, &nitems, &bytesafter, &args) == Success) && (args != NULL) )
@@ -188,11 +195,25 @@ static int Xawtv_QueryRemoteCommand( Window wid, char * pBuffer, int bufLen )
          pBuffer[bufLen - 1] = 0;
          XFree(args);
 
+         dprintf1("Xawtv-QueryRemoteCommand: RECV %s", pBuffer);
          result = 0;
          for (idx=0; idx < nitems; idx++)
+         {
             if (pBuffer[idx] == 0)
+            {
                result += 1;
+
+               if (idx + 1 < nitems)
+                  dprintf1(" %s", pBuffer + idx + 1);
+            }
+         }
+         dprintf1(" (#%d)\n", result);
       }
+      else
+         dprintf0("Xawtv-QueryRemoteCommand: failed to read property\n");
+
+      // remove the dummy error handler
+      Tk_DeleteErrorHandler(errHandler);
    }
    else
       debug0("No Tk display available");
@@ -241,8 +262,10 @@ static int TvSimu_AsyncThreadHandler( ClientData clientData, Tcl_Interp *interp,
 // - this function is called for every incoming X event
 // - filters out events on the pseudo xawtv main window
 //
-static void Xawtv_EventNotification( ClientData clientData, XEvent *eventPtr )
+static int Xawtv_EventNotification( ClientData clientData, XEvent *eventPtr )
 {
+   bool result = FALSE;
+
    if ( (eventPtr->type == PropertyNotify) &&
         (eventPtr->xproperty.window == xawtv_wid) && (xawtv_wid != None) )
    {
@@ -255,7 +278,9 @@ static void Xawtv_EventNotification( ClientData clientData, XEvent *eventPtr )
             Tcl_AsyncMark(asyncThreadHandler);
          }
       }
+      result = TRUE;
    }
+   return result;
 }
 
 // ----------------------------------------------------------------------------
@@ -358,7 +383,7 @@ static void TvSim_XawtvCreateAtoms( void )
          {
             TvSim_XawtvSetStation(0, "1", "ARD");
 
-            Tk_CreateEventHandler(mainWindow, PropertyChangeMask, Xawtv_EventNotification, NULL);
+            Tk_CreateGenericHandler(Xawtv_EventNotification, NULL);
          }
       }
       else
@@ -493,7 +518,6 @@ bool BtDriver_TuneChannel( int inputIdx, uint freq, bool dummy, bool * pIsTuner
    }
 
 #else // __NetBSD__ || __FreeBSD__
-   char * pDevName;
    ulong lfreq;
    uint  norm;
    bool result = FALSE;
@@ -505,26 +529,26 @@ bool BtDriver_TuneChannel( int inputIdx, uint freq, bool dummy, bool * pIsTuner
    {
       if ( (*pIsTuner) && (lfreq != 0) )
       {
-         if (tuner_fd != -1)
+         if (video_fd != -1)
          {
             // mute audio
             int mute_arg = AUDIO_MUTE;
-            if (ioctl (tuner_fd, BT848_SAUDIO, &mute_arg) == 0)
+            if (ioctl (video_fd, BT848_SAUDIO, &mute_arg) == 0)
             {
                dprintf0("Muted tuner audio.\n");
             }
             else
-               fprintf(stderr, "muting audio (ioctl AUDIO_MUTE)\n", strerror(errno));
+               fprintf(stderr, "muting audio (ioctl AUDIO_MUTE): %s\n", strerror(errno));
 
             // Set the tuner frequency
-            if(ioctl(tuner_fd, VIDIOCSFREQ, &lfreq) == 0)
+            if(ioctl(video_fd, TVTUNER_SETFREQ, &lfreq) == 0)
             {
                dprintf1("Vbi-TuneChannel: set to %.2f\n", (double)freq/16);
 
                result = TRUE;
             }
             else
-               fprintf(stderr, "setting tuner frequency (ioctl VIDIOCSFREQ): \n", strerror(errno));
+               fprintf(stderr, "setting tuner frequency (ioctl TVTUNER_SETFREQ): %s\n", strerror(errno));
          }
       }
    }
@@ -557,7 +581,7 @@ static void DisplaySystemErrorMsg( char * message, DWORD code )
       free(buf);
    }
 }
-#endif
+#endif // COMPILE_UNUSED_CODE
 
 // ---------------------------------------------------------------------------
 // Callback to deal with Windows shutdown
